vpnor: create hostboot bootloader partition

The hostboot bootloader code doesn't use mbox.

It has specific requirements:
- The PNOR TOC should be at the 'PNOR end - TOC size - page size'
  offset. It searches for the TOC here, if not found, the search moves
  down page by page.
- The PNOR should be 64M. The page size and erase block should be 4K.
  The TOC should be 32K.

Copy what the bootloader expects to the LPC memory when mboxd starts up.
The same needs to be done in the case of an mbox reset (irrespective of
where the reset comes from).

Skiboot expects that the TOC should be at offset 0, but it uses mbox to
read the TOC. So this commit doesn't impact skiboot requirements.

Change-Id: I7de556dccfea85f2faa5f401177006a3a562494e
Signed-off-by: Deepak Kodihalli <dkodihal@in.ibm.com>
diff --git a/mboxd_dbus.c b/mboxd_dbus.c
index 6673ca6..3f869fe 100644
--- a/mboxd_dbus.c
+++ b/mboxd_dbus.c
@@ -133,12 +133,12 @@
 	}
 
 	/*
 	 * This will close (and flush) the current window and point the lpc bus
 	 * mapping back to flash. Better set the bmc event to notify the host
 	 * of this.
 	 */
 	reset_all_windows(context, SET_BMC_EVENT);
-	rc = point_to_flash(context);
+	rc = reset_lpc(context);
 	if (rc < 0) {
 		return -E_DBUS_HARDWARE;
 	}
@@ -133,12 +133,12 @@
 
 	/*
-	 * This will close (and flush) the current window and point the lpc bus
-	 * mapping back to flash. Better set the bmc event to notify the host
-	 * of this.
+	 * This will close (and flush) the current window and reset the lpc bus
+	 * mapping back to flash, or memory in case we're using a virtual pnor.
+	 * Better set the bmc event to notify the host of this.
 	 */
 	reset_all_windows(context, SET_BMC_EVENT);